@@ -1,10 +1,11 @@
 from constants import *
 import repops
-from itertools import izip_longest
+from itertools import izip_longest, chain
 
 _delay_import_(globals(),"itypes","rtypes","dimpaths","dimensions")
 _delay_import_(globals(),"ops")
 _delay_import_(globals(),"repops_slice")
+_delay_import_(globals(),"repops_funcs")
 _delay_import_(globals(),"utils","util")
 
 class UnpackArray(repops.UnaryOpRep):
@@ -101,9 +102,14 @@ class Shape(repops.UnaryOpRep):
             for pos, dim in enumerate(slice.dims):
                 if dim.name in dimnames:
                     continue
-                nslice = ops.ShapeOp(slice,pos)
+                packdepth = len(slice.dims) - pos - 1
+                nslice = slice
+                if packdepth:        
+                    nslice = ops.PackArrayOp(nslice, packdepth)
+                nslice = ops.ChangeNameOp(nslice, dim.name)  
                 nslices.append(nslice)
                 dimnames.add(dim.name)
+        nslices = repops_funcs.Count._apply(nslices, -1)
         return self._initialize(tuple(nslices))
        
 
@@ -122,6 +128,13 @@ class SplitDim(repops.UnaryOpRep):
         selpath = dimpaths.identifyUniqueDimPathSource(source,dimsel)
         nslices = []
 
+        if not lname or not rname:
+            dimnames = util.seq_names(2, exclude=set([d.name for d in source.DimsUnique]))
+            if not lname:
+                lname = dimnames[0]
+            if not rname:
+                rname = dimnames[1]
+
         if(isinstance(lshape,int)):
             ldim = dimensions.Dim(lshape,name=lname)
         else:
@@ -297,3 +310,46 @@ class GroupIndex(repops.UnaryOpRep):
 
 
 
+def makeDimNamesUnique(*sources):
+    alldims = [source.DimsUnique if not source is None else [] for source in sources]
+    udims = set(chain(*alldims))
+    if len(udims) == len(set([udim.name for udim in udims])):
+        return sources
+    res = {}
+    translate = []
+    for dim in udims:
+        if dim.name in res:
+            translate.append(dim)
+        else:
+            res[dim.name] = dim
+    
+    ntrans = {}
+    for dim in translate:
+        if dim.name in res:
+            odim = res[dim.name]
+            newname = util.append_name(odim.name, exclude=res)
+            res[newname] = odim
+            del res[dim.name]
+            ntrans[odim] = newname
+        
+        newname = util.append_name(dim.name, exclude=res)
+        res[newname] = dim
+        ntrans[dim] = newname
+        
+    nsources = []
+    for dims, source in zip(alldims, sources):
+        if not source is None:
+            rename = [ntrans[dim] if dim in ntrans else dim.name for dim in dims]
+            nsources.append(DimRename(source,*rename))
+        else:
+            nsources.append(None)
+
+    return nsources
+        
+                
+        
+
+
+
+
+
