@@ -57,7 +57,9 @@ class Nest(repops.MultiOpRep):
 class Combine(repops.MultiOpRep):
     def __init__(self, *sources):
         repops.MultiOpRep.__init__(self, sources)
+    
     def _sprocess(self,sources):
+        sources = repops_dim.makeDimNamesUnique(*sources)
         nslices = self._apply(*[source._slices for source in sources])
         return self._initialize(nslices)
 
@@ -158,13 +160,20 @@ class Group(repops.MultiOpRep):
 class Filter(repops.MultiOpRep):
     def __init__(self,source,constraint,dim=LASTCOMMONDIM,mode=None):
         if(not isinstance(constraint,representor.Representor)):
-            constraint = repops.PlusPrefix(python.Rep(constraint,name="filter"))
+            data = python.Rep(constraint, name='filter')
+            dims = data.DimsUnique
+            if dims:
+                dimnames = util.uniqify_names([d.name for d in dims],exclude=set([d.name for d in source.DimsUnique]))
+                data = data%tuple(dimnames)
+            constraint = repops.PlusPrefix(data)
+
         repops.MultiOpRep.__init__(self,(source,constraint),dim=dim,mode=mode)
 
     def _process(self,sources,dim,mode):
-        source,constraint = sources
+        source,constraint = repops_dim.makeDimNamesUnique(*sources)
         if not source._slicesKnown() or not constraint._typesKnown():
             return
+        
         assert len(constraint._slices) == 1, "Filter constraint should have 1 slice"
         cslice = constraint._slices[0]
 
@@ -337,6 +346,9 @@ class Match(repops.MultiOpRep):
         assert (not isinstance(lslice,representor.Representor)), "Representor objects not allowed as lslice. Use context, string or int to indicate slice in lsource"
         assert (not isinstance(rslice,representor.Representor)), "Representor objects not allowed as rslice. Use context, string or int to indicate slice in rsource"
         
+        if rslice is None and lslice is None:
+            lsource,rsource = repops_dim.makeDimNamesUnique(lsource, rsource) 
+ 
         if not rslice is None:
             rslice = rsource.Get(rslice)
         elif not lslice is None:
@@ -348,7 +360,7 @@ class Match(repops.MultiOpRep):
         repops.MultiOpRep.__init__(self,(lsource,rsource,lslice,rslice),jointype=jointype, merge_same=merge_same,mode=mode)
 
     def _process(self, sources, jointype, merge_same,mode):
-        lsource, rsource, lslice,rslice = sources
+        lsource, rsource, lslice, rslice = sources
         if not lsource._slicesKnown() or not rsource._slicesKnown():
             return
         if(lslice is None):
